@@ -1,7 +1,7 @@
 import json
 import requests
 
-__all__ = ['getHome', 'getCategory', 'getLead', 'getUser', 'getTrack', 'getRandom']
+__all__ = ['getFeaturedGhosts', 'getHome', 'getCategory', 'getLead', 'getUser', 'getTrack', 'getRandom']
 
 def getFeaturedGhosts():
     response = requests.get("https://raw.githubusercontent.com/Calculus0972/Official_Featured_Ghosts/master/ghosts.json")
